#ifndef CNCPP_H_
#define CNCPP_H_

extern unsigned int Sys_1s_Rdy;
extern unsigned int KeyRdy;
extern unsigned char KeyValue;
extern unsigned char TimeUpdata;

extern void Sys_1s_Load_Rdy(void);
extern unsigned int GetSystemErrorState(void);
extern void LcdTopCover(unsigned int aClr);
extern void SystemDataTimeUpdata(unsigned char aY, unsigned char aM, unsigned char aD, unsigned char aH, unsigned char aMin, unsigned char aSec);
extern void CppGuiInit(void);
extern void CppFreRun(void);
extern void CppIn(void);
extern void Cpp_1Ms_Task(void);
extern void Cpp_10Ms_Task(void);
extern void Cpp_100Ms_Task(void);

extern void LoadOuterCanRxMsg(unsigned int aIde, unsigned char *p, unsigned char Len);
extern void LoadInnerCanRxMsg(unsigned int aIde, unsigned char *p, unsigned char Len);

extern void DataTimeSet(unsigned char aY, unsigned char aM, unsigned char aD, unsigned char aH, unsigned char aMin, unsigned char aSec,  unsigned char aWk);


extern  void LoadPsBatStateViaKeyPad(unsigned char *p);
extern  void LoadBatStateViaKeyPad(unsigned char aBatSatte);
extern  void PrcDevPrinterState(int aOffline, int aNoPaper);

extern void LoadDebugViaFECTest(unsigned char * p);
extern void LoadStdViaFECBus(unsigned char * p);
extern void SetRpyFECStdCRCError(void);
extern void LoadCRTViaFECBbus(unsigned char * p);

extern void GetCfgViaUartRx(void);
extern void GetWifiViaUartRx(void);
extern void GetCfgViaUsbCdcRx(void);
extern void UsbConfigSetState(unsigned int aState);
extern unsigned int UsbConfigGetState(void);

extern  void LoadExRecordViaMemory(unsigned char *p);

extern void LoadPsBatStateViaKeyPadSub1(unsigned char *p);
extern void LoadPsBatStateViaKeyPadSub2(unsigned char *p);
extern void KeyPadAskPowerCount();
extern void KeyPadSilenceTickClear(void);

extern void GetHwInfo(unsigned char type, unsigned char isVer, unsigned char * pData);
extern void GetPowerCount(unsigned char aMain, unsigned char aSub1, unsigned char aSub2, unsigned char dump);










#endif
















